/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                     **** EDUCACIN CVICA ****
/*
/*                 Ciclo escolar evaluado: 2005 - 2006
/*_____________________________________________________________________________
/*
/*
/*    PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE LA ASIGNATURA DE
/*                      EDUCACIN CVICA EN FORMATO SAS
/*
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale03_2006_Alum_ECiv.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. La sintxis realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas varibles
/*   - Lectura de variables del archivo en formato ASCII
/*   - Declara los valores perdidos por el usuario (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2006_Alum_ECiv.txt
/*         as como el archivo Excale03_2006_Alum_ECiv.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE.
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la libreria y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se crear la base de datos (tabla de datos) Excale03_2006_Alum_ECiv.sas7bdat.
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2006_Alum_ECiv.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS carge los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE ELABORACIN: 9 DE OCTUBRE DE 2007
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum "C:\***\Excale03_2006_Alum_ECiv.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbanas Pblicas"
                       2         ="Rurales Pblicas"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privadas"
                       6         ="Generales"
                       7         ="Tcnicas"
                       8         ="Telesecundarias"
                       9         ="Privadas";
     VALUE  $modF      "UP"      ="Urbanas Pblicas"
                       "RP"      ="Rurales Pblicas"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privadas"
                       "GRAL"    ="Generales"
                       "TEC"     ="Tcnicas"
                       "TV"      ="Telesecundarias"
                       "PRIV"    ="Privadas";
     VALUE $entestdomF "999999"  ="Respuesta omitida";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadcF
                       1         ="Ocho aos o menos"
                       2         ="Nueve aos"
                       3         ="Diez aos"
                       4         ="Once aos o ms"
                       9         ="Respuesta omitida";
     VALUE edad1sF     1         ="Menos de Ocho aos"
                       2         ="Ocho aos"
                       3         ="Nueve aos"
                       4         ="Diez aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE RespF       0         ="Fallo"
                       1         ="Acierto"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       7         ="Reactivo no administrado";
RUN;



DATA INEE.Excale03_2006_Alum_ECiv;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $20
       id_mod             3
       mod                $4
       entest             $6
       entestdom          $6
       alumno             6
       id_instr           $16
       sexo               3
       edad               8
       edadc              3
       edad1sep           8
       edad1sepc          3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       pva_01             3
       pva_02             3
       pva_03             3
       pva_04             3
       pva_05             3
       pva_06             3
       pva_07             3
       pvb_01             3
       pvb_02             3
       pvb_03             3
       pvb_04             3
       pvb_05             3
       pvb_06             3
       pvb_07             3
       pvb_08             3
       pvc_01             3
       pvc_02             3
       pvc_03             3
       pvc_04             3
       pvc_05             3
       pvc_06             3
       pvc_07             3
       pvc_08             3
       pvd_01             3
       pvd_02             3
       pvd_03             3
       pvd_04             3
       pvd_05             3
       pvd_06             3
       pvd_07             3
       pvd_08             3
       pve_01             3
       pve_02             3
       pve_03             3
       pve_04             3
       pve_05             3
       pve_06             3
       pve_07             3
       pve_08             3
       pvf_01             3
       pvf_02             3
       pvf_03             3
       pvf_04             3
       pvf_05             3
       pvf_06             3
       pvf_07             3
       pv1civ             8
       pv2civ             8
       pv3civ             8
       pv4civ             8
       pv5civ             8
       civnvl1            3
       civnvl2            3
       civnvl3            3
       civnvl4            3
       civnvl5            3
       civnvlb1           3
       civnvlb2           3
       civnvlb3           3
       civnvlb4           3
       civnvlb5           3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
   ;

INFILE alum MISSOVER LINESIZE = 1376;
   INPUT
       nacional           1 - 1
       escuela            2 - 5
       id_ent             6 - 7
       nom_ent            8 - 27
       id_mod            28 - 28
       mod               29 - 32
       entest            33 - 38
       entestdom         39 - 44
       alumno            45 - 50
       id_instr          51 - 66
       sexo              67 - 67
       EDAD              68 - 72
       EDADC             73 - 73
       edad1sep          74 - 89
       edad1sepc         90 - 92
       EDADN             93 - 93
       edad_ac           94 - 95
       mes_nac           96 - 97
       w_alu             98 - 113
       docente          114 - 118
       pva_01           119 - 119
       pva_02           120 - 120
       pva_03           121 - 121
       pva_04           122 - 122
       pva_05           123 - 123
       pva_06           124 - 124
       pva_07           125 - 125
       pvb_01           126 - 126
       pvb_02           127 - 127
       pvb_03           128 - 128
       pvb_04           129 - 129
       pvb_05           130 - 130
       pvb_06           131 - 131
       pvb_07           132 - 132
       pvb_08           133 - 133
       pvc_01           134 - 134
       pvc_02           135 - 135
       pvc_03           136 - 136
       pvc_04           137 - 137
       pvc_05           138 - 138
       pvc_06           139 - 139
       pvc_07           140 - 140
       pvc_08           141 - 141
       pvd_01           142 - 142
       pvd_02           143 - 143
       pvd_03           144 - 144
       pvd_04           145 - 145
       pvd_05           146 - 146
       pvd_06           147 - 147
       pvd_07           148 - 148
       pvd_08           149 - 149
       pve_01           150 - 150
       pve_02           151 - 151
       pve_03           152 - 152
       pve_04           153 - 153
       pve_05           154 - 154
       pve_06           155 - 155
       pve_07           156 - 156
       pve_08           157 - 157
       pvf_01           158 - 158
       pvf_02           159 - 159
       pvf_03           160 - 160
       pvf_04           161 - 161
       pvf_05           162 - 162
       pvf_06           163 - 163
       pvf_07           164 - 164
       pv1civ           165 - 180
       pv2civ           181 - 196
       pv3civ           197 - 212
       pv4civ           213 - 228
       pv5civ           229 - 244
       civnvl1          245 - 245
       civnvl2          246 - 246
       civnvl3          247 - 247
       civnvl4          248 - 248
       civnvl5          249 - 249
       civnvlb1         250 - 250
       civnvlb2         251 - 251
       civnvlb3         252 - 252
       civnvlb4         253 - 253
       civnvlb5         254 - 254
       wvarstrr         255 - 256
       w_fstr1          257 - 270
       w_fstr2          271 - 284
       w_fstr3          285 - 298
       w_fstr4          299 - 312
       w_fstr5          313 - 326
       w_fstr6          327 - 340
       w_fstr7          341 - 354
       w_fstr8          355 - 368
       w_fstr9          369 - 382
       w_fstr10         383 - 396
       w_fstr11         397 - 410
       w_fstr12         411 - 424
       w_fstr13         425 - 438
       w_fstr14         439 - 452
       w_fstr15         453 - 466
       w_fstr16         467 - 480
       w_fstr17         481 - 494
       w_fstr18         495 - 508
       w_fstr19         509 - 522
       w_fstr20         523 - 536
       w_fstr21         537 - 550
       w_fstr22         551 - 564
       w_fstr23         565 - 578
       w_fstr24         579 - 592
       w_fstr25         593 - 606
       w_fstr26         607 - 620
       w_fstr27         621 - 634
       w_fstr28         635 - 648
       w_fstr29         649 - 662
       w_fstr30         663 - 676
       w_fstr31         677 - 690
       w_fstr32         691 - 704
       w_fstr33         705 - 718
       w_fstr34         719 - 732
       w_fstr35         733 - 746
       w_fstr36         747 - 760
       w_fstr37         761 - 774
       w_fstr38         775 - 788
       w_fstr39         789 - 802
       w_fstr40         803 - 816
       w_fstr41         817 - 830
       w_fstr42         831 - 844
       w_fstr43         845 - 858
       w_fstr44         859 - 872
       w_fstr45         873 - 886
       w_fstr46         887 - 900
       w_fstr47         901 - 914
       w_fstr48         915 - 928
       w_fstr49         929 - 942
       w_fstr50         943 - 956
       w_fstr51         957 - 970
       w_fstr52         971 - 984
       w_fstr53         985 - 998
       w_fstr54         999 - 1012
       w_fstr55        1013 - 1026
       w_fstr56        1027 - 1040
       w_fstr57        1041 - 1054
       w_fstr58        1055 - 1068
       w_fstr59        1069 - 1082
       w_fstr60        1083 - 1096
       w_fstr61        1097 - 1110
       w_fstr62        1111 - 1124
       w_fstr63        1125 - 1138
       w_fstr64        1139 - 1152
       w_fstr65        1153 - 1166
       w_fstr66        1167 - 1180
       w_fstr67        1181 - 1194
       w_fstr68        1195 - 1208
       w_fstr69        1209 - 1222
       w_fstr70        1223 - 1236
       w_fstr71        1237 - 1250
       w_fstr72        1251 - 1264
       w_fstr73        1265 - 1278
       w_fstr74        1279 - 1292
       w_fstr75        1293 - 1306
       w_fstr76        1307 - 1320
       w_fstr77        1321 - 1334
       w_fstr78        1335 - 1348
       w_fstr79        1349 - 1362
       w_fstr80        1363 - 1376
    ;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       entestdom   = "Variable auxiliar para identificar los dominios de estudio (subpoblaciones donde se reportan resultados) a nivel de modalidad al interior de las entidades"
       alumno      = "Identifcador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       edad        = "Edad del alumno al mes de mayo de 2006, en aos (al momento de la aplicacin)"
       edadc       = "Edad del alumno al mes de mayo de 2006, codificada (al momento de la aplicacin)"
       edad1sep    = "Edad del alumno al mes de septiembre de 2005, en aos (al inicio del ciclo escolar)"
       edad1sepc   = "Edad del alumno al mes de septiembre de 2005, codificada (al inicio del ciclo escolar)"
       edadn       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       pva_01      = "Reactivo PVA_01. Reconocer los beneficios de la comunicacin y el dilogo en la familia"
       pva_02      = "Reactivo PVA_02. Identificar la importancia y ventajas del trabajo en grupo"
       pva_03      = "Reactivo PVA_03. Identificar de fiestas tradicionales nacionales"
       pva_04      = "Reactivo PVA_04. Reconocer y valorar el derecho a respetar y ser respetado: acciones y situaciones"
       pva_05      = "Reactivo PVA_05. Reconocer la importancia de las organizaciones sociales locales"
       pva_06      = "Reactivo PVA_06. Reconocer a los miembros del Ayuntamiento como funcionarios municipales"
       pva_07      = "Reactivo PVA_07. Identificar los beneficios que conlleva elegir el gobierno de la entidad"
       pvb_01      = "Reactivo PVB_01. Reconocer la distribucin de tareas y responsabilidades de los miembros de la familia"
       pvb_02      = "Reactivo PVB_02. Reconocer el valor de satisfacer las necesidades sin aprovecharse de los dems"
       pvb_03      = "Reactivo PVB_03. Reconocer los fines de las organizaciones sociales"
       pvb_04      = "Reactivo PVB_04. Identificar la edad en que se adquiere el derecho de elegir y ser electo"
       pvb_05      = "Reactivo PVB_05. Identificar las funciones del poder legislativo de la entidad"
       pvb_06      = "Reactivo PVB_06. Identificar  los smbolo patrios: Bandera, Escudo e Himno Nacional"
       pvb_07      = "Reactivo PVB_07. Reconocer a la Constitucin Poltica de los Estados Unidos Mexicanos como Ley Suprema para todo en el pas"
       pvb_08      = "Reactivo PVB_08. Reconocer y valorar los derechos del nio: Nombre y Nacionalidad"
       pvc_01      = "Reactivo PVC_01. Identificar formas de satisfacer necesidades mediante el trabajo digno"
       pvc_02      = "Reactivo PVC_02. Valorar la interdependencia laboral a favor de bien comn"
       pvc_03      = "Reactivo PVC_03. Reconocer y valorar los derechos de los nios: Proteccin, Educacin y Salud"
       pvc_04      = "Reactivo PVC_04. Identificar las costumbres familiares"
       pvc_05      = "Reactivo PVC_05. Reconocer el uso adecuado de los servicios pblicos"
       pvc_06      = "Reactivo PVC_06. Identificar los periodos de eleccin federal y estatal"
       pvc_07      = "Reactivo PVC_07. Identificar organizaciones sociales y polticas"
       pvc_08      = "Reactivo PVC_08. Identificar el propsito de las organizaciones sociales y polticas"
       pvd_01      = "Reactivo PVD_01. Reconocer a las autoridades locales y nacionales"
       pvd_02      = "Reactivo PVD_02. Reconocer las desventajas y mejoras del trabajo en grupo"
       pvd_03      = "Reactivo PVD_03. Reconocer y valorar el derecho a respetar y ser respetado: generacin de empata"
       pvd_04      = "Reactivo PVD_04. Identificar las principales funciones de las autoridades municipales"
       pvd_05      = "Reactivo PVD_05. Identificar los beneficios del derecho de elegir y ser electo"
       pvd_06      = "Reactivo PVD_06. Identificar el gobierno federal: Presidente"
       pvd_07      = "Reactivo PVD_07. Reconocer los beneficios sociales y polticos que conlleva contar con la Constitucin"
       pvd_08      = "Reactivo PVD_08. Reconocer y valorar el derecho de los nios: recreacin y descanso"
       pve_01      = "Reactivo PVE_01. Reconocer la importancia de la colaboracin y solidaridad entre los miembros de la familia"
       pve_02      = "Reactivo PVE_02. Identificar el trabajo como la nica manera digna de obtener satisfactores"
       pve_03      = "Reactivo PVE_03. Identificar las funciones del poder ejecutivo de la entidad"
       pve_04      = "Reactivo PVE_04. Identificar la importancia del trabajo en grupo en la resolucin de problemas de la localidad"
       pve_05      = "Reactivo PVE_05. Identificar las ventajas del trabajo en grupo para resolver problemas de la localidad"
       pve_06      = "Reactivo PVE_06. Reconocer las reglas de convivencia en las organizaciones sociales"
       pve_07      = "Reactivo PVE_07. Identificar manifestaciones culturales del pas"
       pve_08      = "Reactivo PVE_08. Reconocer los smbolos patrios como representantes de la identidad nacional"
       pvf_01      = "Reactivo PVF_01. Reconocer y valorar el derecho a respetar y ser respetado: beneficios"
       pvf_02      = "Reactivo PVF_02. Identificar las organizaciones sociales locales"
       pvf_03      = "Reactivo PVF_03. Reconocer al federalismo por medio de la identificacin de autoridades, leyes o normas"
       pvf_04      = "Reactivo PVF_04. Identificar el cuidado de los servicios pblicos"
       pvf_05      = "Reactivo PVF_05. Identificar las elecciones municipalescomo proceso para integrar el Ayuntamiento"
       pvf_06      = "Reactivo PVF_06. Identificar los beneficios de elegir presidente municipal o Delegado en el caso del DF"
       pvf_07      = "Reactivo PVF_07. Identificar las funciones del poder judicial de la entidad"
       pv1civ      = "Primer valor plausible de Educacin Cvica"
       pv2civ      = "Segundo valor plausible de Educacin Cvica"
       pv3civ      = "Tercer valor plausible de Educacin Cvica"
       pv4civ      = "Cuarto valor plausible de Educacin Cvica"
       pv5civ      = "Quinto valor plausible de Educacin Cvica"
       civnvl1     = "Nivel de logro en Educacin Cvica. Asociado a pv1civ. (Cuatro niveles)"
       civnvl2     = "Nivel de logro en Educacin Cvica. Asociado a pv2civ. (Cuatro niveles)"
       civnvl3     = "Nivel de logro en Educacin Cvica. Asociado a pv3civ. (Cuatro niveles)"
       civnvl4     = "Nivel de logro en Educacin Cvica. Asociado a pv4civ. (Cuatro niveles)"
       civnvl5     = "Nivel de logro en Educacin Cvica. Asociado a pv5civ. (Cuatro niveles)"
       civnvlb1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a pv1civ."
       civnvlb2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a pv2civ."
       civnvlb3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a pv3civ."
       civnvlb4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a pv4civ."
       civnvlb5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a pv5civ."
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char20.
       id_mod             id_modF.
       mod                $modF.
       entest             $char6.
       entestdom          $entestdomF.
       alumno             6.
       id_instr           $char16.
       sexo               sexoF.
       edadc              edadcF.
       edad1sepc          edad1sF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       pva_01             RespF.
       pva_02             RespF.
       pva_03             RespF.
       pva_04             RespF.
       pva_05             RespF.
       pva_06             RespF.
       pva_07             RespF.
       pvb_01             RespF.
       pvb_02             RespF.
       pvb_03             RespF.
       pvb_04             RespF.
       pvb_05             RespF.
       pvb_06             RespF.
       pvb_07             RespF.
       pvb_08             RespF.
       pvc_01             RespF.
       pvc_02             RespF.
       pvc_03             RespF.
       pvc_04             RespF.
       pvc_05             RespF.
       pvc_06             RespF.
       pvc_07             RespF.
       pvc_08             RespF.
       pvd_01             RespF.
       pvd_02             RespF.
       pvd_03             RespF.
       pvd_04             RespF.
       pvd_05             RespF.
       pvd_06             RespF.
       pvd_07             RespF.
       pvd_08             RespF.
       pve_01             RespF.
       pve_02             RespF.
       pve_03             RespF.
       pve_04             RespF.
       pve_05             RespF.
       pve_06             RespF.
       pve_07             RespF.
       pve_08             RespF.
       pvf_01             RespF.
       pvf_02             RespF.
       pvf_03             RespF.
       pvf_04             RespF.
       pvf_05             RespF.
       pvf_06             RespF.
       pvf_07             RespF.
       civnvl1            1.
       civnvl2            1.
       civnvl3            1.
       civnvl4            1.
       civnvl5            1.
       civnvlb1           1.
       civnvlb2           1.
       civnvlb3           1.
       civnvlb4           1.
       civnvlb5           1.
       wvarstrr           2.
   ;
/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Multiple.
/*   .S o S = No contestado.
/*************************************************************************/
   IF entestdom = "999999"  THEN entestdom = "S";
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(4)  sexo edadc edad1sepc edadn;
   DO  i=1 TO 4;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(4)  edad edad1sep edad_ac mes_nac;
   DO  i=1 TO 4;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(46)
                   pva_01 pva_02 pva_03 pva_04 pva_05 pva_06 pva_07 pvb_01 pvb_02
                   pvb_03 pvb_04 pvb_05 pvb_06 pvb_07 pvb_08 pvc_01 pvc_02 pvc_03
                   pvc_04 pvc_05 pvc_06 pvc_07 pvc_08 pvd_01 pvd_02 pvd_03 pvd_04
                   pvd_05 pvd_06 pvd_07 pvd_08 pve_01 pve_02 pve_03 pve_04 pve_05
                   pve_06 pve_07 pve_08 pvf_01 pvf_02 pvf_03 pvf_04 pvf_05 pvf_06 pvf_07;
   DO  i=1 TO 46;
          IF (perdidos3{i} = 5 OR  perdidos3{i} = 7)  THEN  perdidos3{i} = .N;
   END;

   drop i;
RUN;
